@@ -57,10 +57,10 @@ class ActivityTypeQuerySet(BaseQuerySet):
             domain,
             type_info['activityType']['name'],
             type_info['activityType']['version'],
-            status=type_info['status'],
-            description=type_info['description'],
-            creation_date=type_info['creationDate'],
-            deprecation_date=type_info['deprecationDate'],
+            status=type_info.get('status'),
+            description=type_info.get('description'),
+            creation_date=type_info.get('creationDate'),
+            deprecation_date=type_info.get('deprecationDate'),
             **kwargs
         )
 
@@ -213,8 +213,9 @@ class ActivityTypeQuerySet(BaseQuerySet):
 
         :param      registration_status: activity type registration status to match,
                                          Valid values are:
-                                        * ``swf.constants.REGISTERED``
-                                        * ``swf.constants.DEPRECATED``
+                                         * ``swf.constants.REGISTERED``
+                                         * ``swf.constants.DEPRECATED``
+
         :type       registration_status: string
 
         :param      name: activity type name to match
@@ -233,8 +234,9 @@ class ActivityTypeQuerySet(BaseQuerySet):
 
         :param      registration_status: activity type registration status to match,
                                          Valid values are:
-                                        * ``swf.constants.REGISTERED``
-                                        * ``swf.constants.DEPRECATED``
+                                         * ``swf.constants.REGISTERED``
+                                         * ``swf.constants.DEPRECATED``
+                                         
         :type       registration_status: string
 
         :returns: list of matched ActivityType models objects
@@ -286,7 +288,7 @@ class ActivityTypeQuerySet(BaseQuerySet):
                task_schedule_to_start_timeout=0,
                task_start_to_close_timeout=0,
                *args, **kwargs):
-        """Creates a new remote activity type and returns the 
+        """Creates a new remote activity type and returns the
         created ActivityType model instance.
 
         :param  name: name of the ActivityType
